@@ -3,19 +3,21 @@ import os
 import sys
 import time 
 
-def pool_init(t, directory, counter):
+def pool_init(t, directory, counter, interactive):
     global dl
     global total_length
     global png_dir
+    global inter
     dl = counter
     total_length = t
     png_dir = directory
+    inter = interactive
 
 def dl_list(infos):
     global dl
     global total_length
     global should_log
-
+    global inter
     for info in infos:
         pic_name = os.path.join(png_dir, info['external_picture_url'].split('/')[-1])
         if not os.path.isfile(pic_name):
@@ -29,8 +31,14 @@ def dl_list(infos):
             except Exception:
                 print(f"Image {pic_name} can't be downloaded")
             done = int(50 * dl.value / total_length)
-            sys.stdout.flush()
-            sys.stdout.write(f"\r[{'=' * done}{' ' * (50 - done)}] {dl.value}/{total_length}")
+            if inter:
+                sys.stdout.flush()
+                sys.stdout.write(f"\r[{'=' * done}{' ' * (50 - done)}] {dl.value}/{total_length}")
+            else:
+                if total_length>100 and (dl.value%50==0 or dl.value==total_length):
+                    print('['+'='* done+' ' * (50 - done)+'] ' + str(dl.value)+'/'+str(total_length))
+                elif total_length<=100 and (dl.value%5==0 or dl.value==total_length):
+                    print('['+'='* done+' ' * (50 - done)+'] ' + str(dl.value)+'/'+str(total_length))
 
 def chunks(lst, n):
     """Yield successive n-sized chunks from lst."""
